@@ -12,10 +12,8 @@
 #include "calendarsupport_export.h"
 #include "printplugin.h"
 
-#include <Akonadi/Calendar/ETMCalendar>
-
+#include <KCalendarCore/Calendar>
 #include <KCalendarCore/Event>
-#include <KCalendarCore/Journal>
 #include <KCalendarCore/Todo>
 
 #include <QDateTime>
@@ -79,10 +77,10 @@ public:
 
     /** HELPER FUNCTIONS */
 public:
-    bool useColors() const;
+    [[nodiscard]] bool useColors() const;
     void setUseColors(bool useColors);
 
-    bool printFooter() const;
+    [[nodiscard]] bool printFooter() const;
     void setPrintFooter(bool printFooter);
 
     /**
@@ -99,7 +97,7 @@ public:
         default value based on the printer orientation.
         @return height of the page header of the printout
     */
-    int headerHeight() const;
+    [[nodiscard]] int headerHeight() const;
     void setHeaderHeight(const int height);
 
     int subHeaderHeight() const;
@@ -109,16 +107,16 @@ public:
         default value based on the printer orientation.
         @return height of the page footer of the printout
     */
-    int footerHeight() const;
+    [[nodiscard]] int footerHeight() const;
     void setFooterHeight(const int height);
 
-    int margin() const;
+    [[nodiscard]] int margin() const;
     void setMargin(const int margin);
 
-    int padding() const;
+    [[nodiscard]] int padding() const;
     void setPadding(const int margin);
 
-    int borderWidth() const;
+    [[nodiscard]] int borderWidth() const;
     void setBorderWidth(const int border);
 
     /*****************************************************************
@@ -419,12 +417,7 @@ public:
       @param holidaysFlags Bitfield consisting of DisplayFlags flags to determine
                            how holidays should be printed.
     */
-    void drawMonth(QPainter &p,
-                   QDate dt,
-                   QRect box,
-                   int maxdays = -1,
-                   int subDailyFlags = TimeBoxes,
-                   int holidaysFlags = Text);
+    void drawMonth(QPainter &p, QDate dt, QRect box, int maxdays = -1, int subDailyFlags = TimeBoxes, int holidaysFlags = Text);
 
     /**
       Internal class representing the start of a todo.
@@ -543,11 +536,11 @@ protected:
     KCalendarCore::Event::Ptr holidayEvent(QDate date) const;
 
 protected:
-    bool mUseColors;    /**< Whether or not to use event category colors to draw the events. */
-    bool mPrintFooter;  /**< Whether or not to print a footer at the bottoms of pages. */
-    bool mShowNoteLines;    /**< Whether or not to print horizontal  lines in note areas. */
-    bool mExcludeConfidential;  /**< Whether or not to print incidences with secrecy "confidential". */
-    bool mExcludePrivate;   /**< Whether or not to print incidences with secrecy "private". */
+    bool mUseColors; /**< Whether or not to use event category colors to draw the events. */
+    bool mPrintFooter; /**< Whether or not to print a footer at the bottoms of pages. */
+    bool mShowNoteLines; /**< Whether or not to print horizontal  lines in note areas. */
+    bool mExcludeConfidential; /**< Whether or not to print incidences with secrecy "confidential". */
+    bool mExcludePrivate; /**< Whether or not to print incidences with secrecy "private". */
     int mHeaderHeight;
     int mSubHeaderHeight;
     int mFooterHeight;
@@ -573,4 +566,3 @@ private:
     QColor getTextColor(const QColor &c) const;
 };
 }
-
